Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrReadTimeout = errors.New("Ray: timeout.")
Functions ¶
This section is empty.
Types ¶
type InboundRay ¶
type InboundRay interface {
// InboundInput provides a stream to retrieve the request from client.
// The inbound connection shall close the channel after the entire request
// is received and put into the channel.
InboundInput() OutputStream
// InboudBound provides a stream of data for the inbound connection to write
// as response. The inbound connection shall write all the data from the
// channel until it is closed.
InboundOutput() InputStream
}
InboundRay is a transport interface for inbound connections.
type InputStream ¶ added in v1.11.1
type InspectorChain ¶
func (*InspectorChain) AddInspector ¶
func (ic *InspectorChain) AddInspector(inspector Inspector)
func (*InspectorChain) Input ¶
func (ic *InspectorChain) Input(b *buf.Buffer)
type NoOpInspector ¶
type NoOpInspector struct{}
func (NoOpInspector) Input ¶
func (NoOpInspector) Input(*buf.Buffer)
type OutboundRay ¶
type OutboundRay interface {
// OutboundInput provides a stream for the input of the outbound connection.
// The outbound connection shall write all the input until it is closed.
OutboundInput() InputStream
// OutboundOutput provides a stream to retrieve the response from the
// outbound connection. The outbound connection shall close the channel
// after all responses are receivced and put into the channel.
OutboundOutput() OutputStream
}
OutboundRay is a transport interface for outbound connections.
type OutputStream ¶ added in v1.11.1
type Ray ¶
type Ray interface {
InboundRay
OutboundRay
AddInspector(Inspector)
}
Ray is an internal tranport channel between inbound and outbound connection.
type Stream ¶ added in v1.11.1
type Stream struct {
// contains filtered or unexported fields
}
func (*Stream) CloseError ¶
func (v *Stream) CloseError()
func (*Stream) ReadTimeout ¶
Click to show internal directories.
Click to hide internal directories.